X-Git-Url: https://git.p6c8.net/jirafeau_project.git/blobdiff_plain/f58031f40640cc7c243a32d2c3515210ef4ed282..f053c68ee0ce3ead5ea5b208de9d73fdd0b08ec4:/lib/config.original.php?ds=sidebyside
diff --git a/lib/config.original.php b/lib/config.original.php
index fa0f034..05631e6 100644
--- a/lib/config.original.php
+++ b/lib/config.original.php
@@ -15,7 +15,7 @@
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see .
+ * along with this program. If not, see .
*/
/*
@@ -34,17 +34,15 @@ $cfg['var_root'] = '';
*/
$cfg['lang'] = 'auto';
/* Select your style :) See media folder */
-$cfg['style'] = 'modern';
-/* Propose a preview link if file type is previewable is set to true. */
+$cfg['style'] = 'courgette';
+/* Propose a preview link if file type is previewable. */
$cfg['preview'] = true;
-/* Download page: propose a link to a download page is set to true. */
-$cfg['download_page'] = true;
/* Encryption feature. disable it by default.
* By enabling it, file-level deduplication won't work.
*/
$cfg['enable_crypt'] = false;
-/* Split lenght of link refenrece. */
-$cfg['link_name_lenght'] = 8;
+/* Split length of link refenrece. */
+$cfg['link_name_length'] = 8;
/* Upload password(s). Empty array disable password authentification.
* $cfg['upload_password'] = array(); // No password
* $cfg['upload_password'] = array('psw1'); // One password
@@ -52,6 +50,13 @@ $cfg['link_name_lenght'] = 8;
* ... and so on
*/
$cfg['upload_password'] = array();
+/* List of IP allowed to upload a file.
+ * If list is empty, then there is no upload restriction based on IP
+ * Elements of the list can be a single IP (e.g. "123.45.67.89") or
+ * an IP range (e.g. "123.45.0.0/16").
+ * Note that CIDR notation is available for IPv4 only for the moment.
+ */
+$cfg['upload_ip'] = array();
/* An empty admin password will disable the classic admin password
* authentication.
*/
@@ -80,6 +85,17 @@ $cfg['availabilities'] = array ('minute' => true,
'month' => true,
'year' => false,
'none' => false);
+/* Set maximal upload size expressed in MB.
+ * 0 mean unlimited upload size.
+ */
+$cfg['maximal_upload_size'] = 0;
+/* If your Jirafeau is behind some reverse proxies, you can set there IPs
+ * so Jirafeau get visitor's IP from HTTP_X_FORWARDED_FOR instead of
+ * REMOTE_ADDR.
+ * for example:
+ * $cfg['proxy_ip'] = array('12.34.56.78');
+ */
+$cfg['proxy_ip'] = array();
/* Installation is done ? */
$cfg['installation_done'] = false;